// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:wyatt_ui_components/wyatt_wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/src/components/buttons/cubit/button_cubit.dart';
import 'package:wyatt_ui_kit/wyatt_ui_kit.dart';

class FileSelectionButtonThemeResolver extends ThemeResolver<
    FileSelectionButtonStyle, FileSelectionButtonThemeExtension, ButtonState> {
  const FileSelectionButtonThemeResolver({
    required this.computeExtensionValueFn,
    required this.customStyleFn,
  });

  @override
  FileSelectionButtonStyle computeDefaultValue(
    BuildContext context, {
    ButtonState? extra,
  }) {
    MultiColor backgroundColor = MultiColor.single(context.colorScheme.primary);
    MultiColor foregroundColor =
        MultiColor.single(context.colorScheme.onPrimary);

    switch (extra?.state) {
      case ControlState.disabled:
        backgroundColor =
            MultiColor.single(context.colorScheme.onSurface.withOpacity(0.12));
        foregroundColor =
            MultiColor.single(context.colorScheme.onSurface.withOpacity(0.38));
        break;
      case ControlState.hovered:
        backgroundColor =
            MultiColor.single(context.colorScheme.primary.withOpacity(0.92));
        break;
      case ControlState.tapped:
        backgroundColor =
            MultiColor.single(context.colorScheme.primary.withOpacity(0.92));
        break;
      case null:
      case ControlState.normal:
      case ControlState.focused:
        break;
    }

    if (extra?.isInvalid ?? false) {
      backgroundColor =
            MultiColor.single(context.colorScheme.error);
    }

    return FileSelectionButtonStyle(
      title: context.textTheme.labelLarge,
      subTitle: context.textTheme.labelSmall,
      radius: (context.buttonTheme.shape is RoundedRectangleBorder)
          ? (context.buttonTheme.shape as RoundedRectangleBorder).borderRadius
          : null,
      padding: const EdgeInsets.symmetric(horizontal: 10),
      foregroundColors: foregroundColor,
      backgroundColors: backgroundColor,
    );
  }

  @override
  final FileSelectionButtonStyle? Function(
    BuildContext context,
    FileSelectionButtonStyle defaultValue,
    FileSelectionButtonThemeExtension themeExtension, {
    ButtonState? extra,
  }) computeExtensionValueFn;

  @override
  final FileSelectionButtonStyle? Function(
    BuildContext context, {
    ButtonState? extra,
  }) customStyleFn;
}
